# Copyright 2020-2022 Le Filament (<https://le-filament.com>)
# License AGPL-3 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class ExportJournalType(models.Model):
    _name = "export.journal.type"
    _description = "Configuration des exports de journaux"
    _order = "sequence"

    name = fields.Char("Nom", required=True)
    active = fields.Boolean("Actif", default=True)
    sequence = fields.Integer(default=10)
    fields_ids = fields.One2many(
        comodel_name="export.journal.field",
        inverse_name="export_id",
        string="Champs",
        copy=True,
    )
    group_ids = fields.One2many(
        comodel_name="export.journal.group",
        inverse_name="export_id",
        string="Groupes",
        copy=True,
    )
    is_header = fields.Boolean("Header", default=True)
    is_group_header = fields.Boolean("Header Group", default=False)
    company_id = fields.Many2one(
        comodel_name="res.company",
        string="Company",
        required=True,
        default=lambda self: self.env["res.company"]._company_default_get(
            "export.journal.type"
        ),
    )
    journal_ids = fields.Many2many(
        comodel_name="account.journal", string="Journaux", copy=True
    )
    order_by = fields.Char(
        string="Ordre d'affichage",
        help="Liste des champs du modèle ex: move_id, partner_id",
    )
    delimiter = fields.Char("Séparateur", default=";")
    csv_datestyle = fields.Char("Format Date CSV", default="%Y-%m-%d")
    xls_datestyle = fields.Char("Format Date XLS", default="YYYY-MM-DD")
    export_domain = fields.Char(string="Export filter")
