# Copyright 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class ExportJournalWizard(models.TransientModel):
    _name = "export.journal.wizard"
    _description = "Wizard export journal"

    @api.model
    def _get_default_company(self):
        return self.env.company

    @api.model
    def _get_default_export(self):
        export = self.env["export.journal.type"].search(
            [("company_id", "=", self.env.user.company_id.id)], limit=1
        )
        return export

    date_start = fields.Date("Date de début", required=True)
    date_end = fields.Date(
        string="Date de fin", required=True, default=fields.Date.today()
    )
    export_format = fields.Selection(
        [("csv", "CSV"), ("xls", "Excel")], string="Format", default="csv"
    )
    company_id = fields.Many2one(
        comodel_name="res.company", default=_get_default_company
    )
    export_id = fields.Many2one(
        comodel_name="export.journal.type",
        string="Format d'export",
        domain="[('company_id', '=', company_id)]",
        default=_get_default_export,
    )
    export_type = fields.Selection(
        [("empty", "Ecritures non exportées"), ("all", "Toutes les écritures")],
        string="Ecritures à exporter",
        default="empty",
    )

    def get_data_file(self):
        """
        Appelle l'url de traitement et de téléchargement
        :return: ir.actions.act_url
        """
        return {
            "type": "ir.actions.act_url",
            "url": "/web/export_journal?export_format=%s&export=%s&export_type=%s"
            % (self.export_format, self.export_id.id, self.export_type)
            + "&date_start=%s&date_end=%s" % (self.date_start, self.date_end),
            "target": "new",
        }
